from __future__ import annotations

from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import (
    MAXIMUM,
    ON,
    TRUE,
    Boolean,
    SymbolicConstant,
)
from ..UtilityAndView.abaqusConstants import abaqusConstants as C
from .GeometricRestriction import GeometricRestriction


@abaqus_class_doc
class ShapeRotationalSymmetry(GeometricRestriction):
    """The ShapeRotationalSymmetry object defines a shape rotational symmetry geometric restriction. The
    ShapeRotationalSymmetry object is derived from the GeometricRestriction object.

    .. note::
        This object can be accessed by::

            import optimization
            mdb.models[name].optimizationTasks[name].geometricRestrictions[name]
    """

    #: A String specifying the geometric restriction repository key.
    name: str

    #: A VertexArray object of length 2 specifying the vector positioned at the **csys** origin,
    #: used as the axis of symmetry. Instead of through a ConstrainedSketchVertex, each point might be specified
    #: through a tuple of coordinates.
    clientDirection: tuple

    #: A Region object specifying the region to which the geometric restriction is applied.
    #: When used with a TopologyTask, there is no default value. When used with a ShapeTask,
    #: the default value is MODEL.
    region: Region

    #: A Float specifying the segment size of the repeating pattern in degrees. If the **angle**
    #: value is 0, no repeating pattern is created. The default value is 0.0.
    angle: float = 0

    #: None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
    #: global coordinate system is used. When this member is queried, it returns an Int. The
    #: default value is None.
    csys: int | None = None

    #: A Boolean specifying whether to allow a nonsymmetric mesh for this geometric
    #: restriction. The default value is TRUE.
    #:
    #: .. versionadded:: 2021
    #:     The ``allowNonSymmetricMesh`` attribute was added.
    allowNonSymmetricMesh: Boolean = TRUE

    #: None or a Region object specifying the master point used when **masterPointDetermination** is
    #: SPECIFY. The default value is None.
    masterPoint: str | None = None

    #: A SymbolicConstant specifying the rule for determining the master node. Possible values
    #: are MAXIMUM, MINIMUM, and SPECIFY. The default value is MAXIMUM.
    masterPointDetermination: SymbolicConstant = MAXIMUM

    #: A Boolean specifying whether to ignore the geometric restriction in the first design
    #: cycle. The default value is ON.
    presumeFeasibleRegionAtStart: Boolean = ON

    #: A tuple of Floats representing the coordinates of a start point of the rotational
    #: symmetry.
    startPoint: float | None = None

    #: A Float specifying the geometric tolerance in the 1-direction. The default value is
    #: 0.01.
    tolerance1: float = 0

    #: A Float specifying the geometric tolerance in the 2-direction. The default value is
    #: 0.01.
    tolerance2: float = 0

    #: A Float specifying the geometric tolerance in the 3-direction. The default value is
    #: 0.01.
    tolerance3: float = 0

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        clientDirection: tuple,
        region: Region,
        allowNonSymmetricMesh: Boolean = TRUE,
        angle: float = 0,
        csys: int | None = None,
        masterPoint: str | None = None,
        masterPointDetermination: Literal[C.SPECIFY, C.MINIMUM, C.MAXIMUM] = MAXIMUM,
        presumeFeasibleRegionAtStart: Boolean = ON,
        startPoint: float | None = None,
        tolerance1: float = 0,
        tolerance2: float = 0,
        tolerance3: float = 0,
    ):
        """This method creates a ShapeRotationalSymmetry object.

        .. note::
            This function can be accessed by::

                mdb.models[name].optimizationTasks[name].ShapeRotationalSymmetry

        Parameters
        ----------
        name
            A String specifying the geometric restriction repository key.
        clientDirection
            A VertexArray object of length 2 specifying the vector positioned at the **csys** origin,
            used as the axis of symmetry. Instead of through a ConstrainedSketchVertex, each point might be specified
            through a tuple of coordinates.
        region
            A Region object specifying the region to which the geometric restriction is applied.
            When used with a TopologyTask, there is no default value. When used with a ShapeTask,
            the default value is MODEL.
        allowNonSymmetricMesh
            A Boolean specifying whether to allow a nonsymmetric mesh for this geometric
            restriction. The default value is TRUE.

            .. versionadded:: 2021
                The ``alloowNonSymmetricMesh`` argument was added.
        angle
            A Float specifying the segment size of the repeating pattern in degrees. If the **angle**
            value is 0, no repeating pattern is created. The default value is 0.0.
        csys
            None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
            global coordinate system is used. When this member is queried, it returns an Int. The
            default value is None.
        masterPoint
            None or a Region object specifying the master point used when **masterPointDetermination** is
            SPECIFY. The default value is None.
        masterPointDetermination
            A SymbolicConstant specifying the rule for determining the master node. Possible values
            are MAXIMUM, MINIMUM, and SPECIFY. The default value is MAXIMUM.
        presumeFeasibleRegionAtStart
            A Boolean specifying whether to ignore the geometric restriction in the first design
            cycle. The default value is ON.
        startPoint
            A tuple of Floats representing the coordinates of a start point of the rotational
            symmetry.
        tolerance1
            A Float specifying the geometric tolerance in the 1-direction. The default value is
            0.01.
        tolerance2
            A Float specifying the geometric tolerance in the 2-direction. The default value is
            0.01.
        tolerance3
            A Float specifying the geometric tolerance in the 3-direction. The default value is
            0.01.

        Returns
        -------
        ShapeRotationalSymmetry
            A ShapeRotationalSymmetry object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        allowNonSymmetricMesh: Boolean = TRUE,
        angle: float = 0,
        csys: int | None = None,
        masterPoint: str | None = None,
        masterPointDetermination: Literal[C.SPECIFY, C.MINIMUM, C.MAXIMUM] = MAXIMUM,
        presumeFeasibleRegionAtStart: Boolean = ON,
        startPoint: float | None = None,
        tolerance1: float = 0,
        tolerance2: float = 0,
        tolerance3: float = 0,
    ):
        """This method modifies the ShapeRotationalSymmetry object.

        Parameters
        ----------
        allowNonSymmetricMesh
            A Boolean specifying whether to allow a nonsymmetric mesh for this geometric
            restriction. The default value is TRUE.
        angle
            A Float specifying the segment size of the repeating pattern in degrees. If the **angle**
            value is 0, no repeating pattern is created. The default value is 0.0.
        csys
            None or a DatumCsys object specifying the local coordinate system. If **csys** = None, the
            global coordinate system is used. When this member is queried, it returns an Int. The
            default value is None.
        masterPoint
            None or a Region object specifying the master point used when **masterPointDetermination** is
            SPECIFY. The default value is None.
        masterPointDetermination
            A SymbolicConstant specifying the rule for determining the master node. Possible values
            are MAXIMUM, MINIMUM, and SPECIFY. The default value is MAXIMUM.
        presumeFeasibleRegionAtStart
            A Boolean specifying whether to ignore the geometric restriction in the first design
            cycle. The default value is ON.
        startPoint
            A tuple of Floats representing the coordinates of a start point of the rotational
            symmetry.
        tolerance1
            A Float specifying the geometric tolerance in the 1-direction. The default value is
            0.01.
        tolerance2
            A Float specifying the geometric tolerance in the 2-direction. The default value is
            0.01.
        tolerance3
            A Float specifying the geometric tolerance in the 3-direction. The default value is
            0.01.
        """
        ...



from __future__ import annotations

from .constants import DEFAULT_SPACING
from .FXComposite import FXComposite
from .FXPacker import FXPacker


class FXHorizontalFrame(FXPacker):
    """Horizontal frame layout manager widget is used to automatically place child-windows horizontally from
    left-to-right, or right-to-left, depending on the child window's layout hints."""

    def __init__(
        self,
        p: FXComposite,
        opts: int = 0,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = DEFAULT_SPACING,
        pr: int = DEFAULT_SPACING,
        pt: int = DEFAULT_SPACING,
        pb: int = DEFAULT_SPACING,
        hs: int = DEFAULT_SPACING,
        vs: int = DEFAULT_SPACING,
    ):
        """Construct a horizontal frame layout manager.

        Parameters
        ----------
        p : FXComposite

        opts : int

        x : int

        y : int

        w : int

        h : int

        pl : int

        pr : int

        pt : int

        pb : int

        hs : int

        vs : int
        """

    def getDefaultHeight(self):
        """Return default height.

        Reimplemented from FXPacker. Reimplemented in FXStatusbar.
        """

    def getDefaultWidth(self):
        """Return default width.

        Reimplemented from FXPacker. Reimplemented in FXStatusbar. By clicking on Send, you accept that Dassault Systèmes will process your personal data and may contact you for further information. [Privacy Policy](https://www.3ds.com/privacy-policy). Total Results: Results per page This page cannot be found. The page might not exist or is temporarily unavailable. Try again or try searching for the topic. Provide Feedback on This Topic Use this form to provide feedback on this help topic. To get product support or to provide product feedback, go to [Frequently Asked Questions](https://3ds.one/PO). For support for online purchased solutions, go to [Online Purchase Support](https://3ds.one/Q8). * Required Subject: Feedback on User Assistance * I acknowledge I have read and I hereby accept the [privacy policy](https://www.3ds.com/privacy-policy) under which my personal data will be used by Dassault Systèmes. 2016 - Go to 2016 home page 2017 - Go to the same topic in 2017 2018 - Go to the same topic in 2018 2019 - Go to the same topic in 2019 2020 - Go to the same topic in 2020 2021 - Go to the same topic in 2021 2022 - Go to the same topic in 2022 2023 - Go to the same topic in 2023 2016 - Go to 2016 home page 2017 - Go to the same topic in 2017 2018 - Go to the same topic in 2018 2019 - Go to the same topic in 2019 2020 - Go to the same topic in 2020 2021 - Go to the same topic in 2021 2022 - Go to the same topic in 2022 2023 - Go to the same topic in 2023
        """



from __future__ import annotations

from .AFXGuiObjectManager import AFXGuiObjectManager
from .AFXMenuPane import AFXMenuPane
from .AFXMenuTitle import AFXMenuTitle
from .AFXTarget import AFXTarget
from .AFXToolsetGui import AFXToolsetGui
from .constants import DECOR_ALL
from .FXApp import FXApp
from .FXIcon import FXIcon
from .FXMainWindow import FXMainWindow
from .FXMenubar import FXMenubar
from .FXSelector import FXSelector
from .FXTabItem import FXTabItem
from .PluginToolset import PluginToolset


class AFXMainWindow(FXMainWindow):
    """This class is responsible for constructing the components of the main window.

    It also provides accessors for the various components constructed.
    """

    #: Used to handle the quit message.
    ID_QUIT: int = hash("ID_QUIT")

    #: Used to handle tabbing.
    ID_TAB: int = hash("ID_TAB")

    #: Toggle the visibility of the model tree.
    ID_TOGGLE_MODEL_TREE: int = hash("ID_TOGGLE_MODEL_TREE")

    #: Toggle full screen.
    ID_TOGGLE_FULL_SCREEN: int = hash("ID_TOGGLE_FULL_SCREEN")

    #: Do not use, do not delete; for use by derived classes.
    ID_LAST: int = hash("ID_LAST")

    def __init__(
        self,
        app: FXApp,
        title: str,
        icon: FXIcon | None = None,
        miniIcon: FXIcon | None = None,
        opts: int = DECOR_ALL,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
    ):
        """Constructor.

        Parameters
        ----------
        app : FXApp
            FXApp object.
        title : str
            Main window title.
        icon : FXIcon | None
            Main window icon.
        miniIcon : FXIcon | None
            Minimized icon.
        opts : int
            Main window options.
        x : int
            X location of the main window.
        y : int
            Y location of the main window.
        w : int
            Width of the main window.
        h : int
            Height of the main window.
        """

    def appendApplicableModuleForTreeTab(self, name: str, moduleName: str):
        """Appends a module name to the list of modules to which a tree tab is applicable.

        Parameters
        ----------
        name : str
            Name of the tab item.
        moduleName : str
            Module name to be appended to the list of the tab's applicable modules.
        """

    def appendTreeTab(self, text: str, name: str):
        """Appends a new tab item to the tree toolset tab book and returns a vertical frame managed by the new
        tab item; you must call create() on the vertical frame after you construct all its child widgets.

        Parameters
        ----------
        text : str
            Text to be shown in the new tab item.
        name : str
            Name of the new tab item.
        """

    def appendVisibleModuleForTreeTab(self, name: str, moduleName: str):
        """Appends a module to the list of modules in which a tree tab is visible.

        Parameters
        ----------
        name : str
            Name of the tab item.
        moduleName : str
            Module name to be appended to the list of the tab's modules in which it is visible.
        """

    def create(self):
        """Virtual base class method for creating windowing system resources.

        Reimplemented from FXTopWindow.
        """

    def getContextBar(self):
        """Returns a pointer to the context bar container."""

    def getCurrentTreeTab(self) -> FXTabItem:  # type: ignore
        """Returns the current tab item."""

    def getDefaultHeight(self) -> int:  # type: ignore
        """Returns the default main window height.

        Reimplemented from FXTopWindow.
        """

    def getDefaultWidth(self) -> int:  # type: ignore
        """Returns the default main window width.

        Reimplemented from FXTopWindow.
        """

    def getDisplayedNameAtIndex(self, index: int) -> str:  # type: ignore
        """Returns the displayed name at the given position in the list.

        Parameters
        ----------
        index : int
            Position in the module list.
        """

    def getDrawingAreaHeight(self) -> int:  # type: ignore
        """Returns the height of the drawing area in pixels."""

    def getDrawingAreaWidth(self) -> int:  # type: ignore
        """Returns the width of the drawing area in pixels."""

    def getHelpToolset(self):
        """Returns a pointer to the help toolset."""

    def getMenubar(self) -> FXMenubar:  # type: ignore
        """Returns a pointer to the menubar."""

    def getModule(self, name: str):
        """Returns the module specified by the given name argument.

        Parameters
        ----------
        name : str
            A String that specifies the module to get.
        """

    def getModuleName(self, displayedName: str) -> str:  # type: ignore
        """Returns the module name for the given displayed name.

        Parameters
        ----------
        displayedName : str
            Displayed module name (English).
        """

    def getNumModules(self) -> int:  # type: ignore
        """Returns the number of modules."""

    def getPluginToolset(self) -> PluginToolset:  # type: ignore
        """Returns the Plugin toolset."""

    def getSelectorFromFunction(self, function: str) -> FXSelector:  # type: ignore
        """Returns the selector of the given shortcut function. Throws exception if not found.

        Parameters
        ----------
        function : str
            A String specifying the function as shown in the Customize dialog box.
        """

    def getTargetFromFunction(self, function: str) -> AFXTarget:  # type: ignore
        """Returns the target of the given shortcut function. Throws exception if not found.

        Parameters
        ----------
        function : str
            A String specifying the function as shown in the Customize dialog box.
        """

    def getToolbox(self):
        """Returns a pointer to the module toolbox container."""

    def getToolMenuPane(self) -> AFXMenuPane:  # type: ignore
        """Returns a pointer to the tools menu pane."""

    def getToolMenuTitle(self) -> AFXMenuTitle:  # type: ignore
        """Returns a pointer to the Tools menu title."""

    def getToolset(self, name: str):
        """Returns the toolset specified by the given name argument.

        Parameters
        ----------
        name : str
            A String in the local language that specifies to toolset to get.
        """

    def getToolsetKernelInitializationCommands(self):
        """Returns the command string that should initialize the toolsets in the kernel that are corresponding
        to the toolsets registered with the main window."""

    def getWorkDirectory(self) -> str:  # type: ignore
        """Returns the current working directory."""

    def hideCli(self):
        """Hides the command line interface."""

    def hideMessageArea(self):
        """Hides the message area interface."""

    def makeCustomToolsets(self):
        """This method has no base class implementation; it may be used by customizers to construct Abaqus/CAE
        toolsets or toolsets derived from Abaqus/CAE toolsets; constructing those toolsets in this method is
        necessary to insure that the toolset will be available to standard Abaqus/CAE modules that register that
        toolset, and to avoid creating duplicate widgets when the toolset is used by a custom toolset."""

    def registerHelpToolset(self, tool: AFXToolsetGui, opts: int):
        """Registers the Help toolset.

        Parameters
        ----------
        tool : AFXToolsetGui
            Pointer to toolset being registered.
        opts : int
            Options for creating toolset GUI components.
        """

    def registerModule(self, displayedName: str, moduleImportName: str, kernelInitializationCommand: str):
        """Registers a module to make it available in the module combo; also registers the initialization string
        to be sent to the kernel the first time the module is loaded.

        Parameters
        ----------
        displayedName : str
            The name that will be displayed in the Module combo box in the context bar.
        moduleImportName : str
            The name that will be used to import this module.
        kernelInitializationCommand : str
            The Python command sent to kernel when the module is loaded.
        """

    def registerToolset(self, tool: AFXGuiObjectManager, opts: int):
        """Registers a toolset that is always available in the main window.

        Parameters
        ----------
        tool : AFXGuiObjectManager
            Pointer to the object being registered.
        opts : int
            Options for creating toolset GUI components.
        """

    def setApplicabilityForTreeTab(self, name: str, moduleNames: str):
        """Sets the modules that are applicable to the given tree tab. When switching modules, if the current
        tab is applicable to the new module, it will remain current. When a tree tab is created, it is
        applicable to all modules--use this method to set the applicability to only certain modules.

        Parameters
        ----------
        name : str
            Name of the tab item.
        moduleNames : str
            A String containing module names separated by commas.
        """

    def setCurrentTreeTab(self, name: str):
        """Sets the tree toolset tab book's current tab item to the tab item specified by the given name.

        Parameters
        ----------
        name : str
            Name of the tab item to be set current.
        """

    def setVisibilityForTreeTab(self, name: str, moduleNames: str):
        """Sets the modules in which a tree tab is visible. When switching modules, if the tab has not been
        specified to be visible in the new module, the tab will be hidden; otherwise it will be shown. When a
        tree tab is created it is visible in all modules--use this method to set the visibility to only certain
        modules.

        Parameters
        ----------
        name : str
            Name of the tab item.
        moduleNames : str
            A String containing module names separated by commas.
        """

    def setWorkDirectory(self, directory: str):
        """Sets the current working directory.

        Parameters
        ----------
        directory : str
            A String specifying the new work directory.
        """

    def showCli(self):
        """Shows the command line interface."""

    def showMessageArea(self):
        """Shows the message area interface."""

    def writeToMessageArea(self, message: str):
        """Writes a string to the message area.

        Parameters
        ----------
        message : str
        """



from __future__ import annotations

from .FXIcon import FXIcon
from .FXShell import FXShell

#: Borderless window.
DECOR_NONE: int = hash("DECOR_NONE")

#: Window title.
DECOR_TITLE: int = hash("DECOR_TITLE")

#: Minimize button.
DECOR_MINIMIZE: int = hash("DECOR_MINIMIZE")

#: Maximize button.
DECOR_MAXIMIZE: int = hash("DECOR_MAXIMIZE")

#: Close button.
DECOR_CLOSE: int = hash("DECOR_CLOSE")

#: Border.
DECOR_BORDER: int = hash("DECOR_BORDER")

#: Resize handles.
DECOR_RESIZE: int = hash("DECOR_RESIZE")

#: Window menu.
DECOR_MENU: int = hash("DECOR_MENU")

#: Place it at the default size and location.
PLACEMENT_DEFAULT: int = hash("PLACEMENT_DEFAULT")

#: Place window to be fully visible.
PLACEMENT_VISIBLE: int = hash("PLACEMENT_VISIBLE")

#: Place it under the cursor position.
PLACEMENT_CURSOR: int = hash("PLACEMENT_CURSOR")

#: Place it centered on its owner.
PLACEMENT_OWNER: int = hash("PLACEMENT_OWNER")

#: Place it centered on the screen.
PLACEMENT_SCREEN: int = hash("PLACEMENT_SCREEN")

#: Place it maximized to the screen size.
PLACEMENT_MAXIMIZED: int = hash("PLACEMENT_MAXIMIZED")


class FXTopWindow(FXShell):
    """Abstract base class for all top-level windows."""

    def create(self):
        """Create server-side resources.

        Reimplemented from FXShell. Reimplemented in FXPrintDialog, FXToolbarShell, AFXMainWindow, and
        AFXDialog.
        """

    def deiconify(self):
        """Deiconify window."""

    def detach(self):
        """Detach the server-side resources for this window.

        Reimplemented from FXComposite.
        """

    def getDecorations(self):
        """Return current title and border decorations."""

    def getDefaultHeight(self):
        """Return the default height of this window.

        Reimplemented from FXComposite. Reimplemented in FXToolbarShell, and AFXMainWindow.
        """

    def getDefaultWidth(self):
        """Return the default width of this window.

        Reimplemented from FXComposite. Reimplemented in FXToolbarShell, and AFXMainWindow.
        """

    def getHSpacing(self):
        """Return horizontal spacing between children."""

    def getIcon(self):
        """Return window icon."""

    def getMiniIcon(self):
        """Return window mini (title) icon."""

    def getPackingHints(self):
        """Return packing hints for children."""

    def getPadBottom(self):
        """Get bottom interior padding."""

    def getPadLeft(self):
        """Get left interior padding."""

    def getPadRight(self):
        """Get right interior padding."""

    def getPadTop(self):
        """Get top interior padding."""

    def getTitle(self):
        """Return window title."""

    def getVSpacing(self):
        """Return vertical spacing between children."""

    def hide(self):
        """Hide this window.

        Reimplemented from FXWindow. Reimplemented in AFXManagerMenuDB, AFXDialog, and AFXMessageDialog.
        """

    def iconify(self):
        """Iconify window."""

    def isIconified(self):
        """Return True if window has been iconified."""

    def killFocus(self):
        """Remove the focus from this window.

        Reimplemented from FXShell.
        """

    def move(self, x: int, y: int):
        """Move this window to the specified position in the parent's coordinates. Reimplemented from FXWindow.

        Parameters
        ----------
        x : int

        y : int
        """

    def place(self, placement: int):
        """Position the window based on placement.

        Parameters
        ----------
        placement : int
        """

    def position(self, x: int, y: int, w: int, h: int):
        """Move and resize this window in the parent's coordinates. Reimplemented from FXWindow.

        Parameters
        ----------
        x : int

        y : int

        w : int

        h : int
        """

    def resize(self, w: int, h: int):
        """Resize this window to the specified width and height. Reimplemented from FXWindow.

        Parameters
        ----------
        w : int

        h : int
        """

    def setDecorations(self, decorations: int):
        """Change title and border decorations.

        Parameters
        ----------
        decorations : int
        """

    def setFocus(self):
        """Move the focus to this window.

        Reimplemented from FXShell.
        """

    def setHSpacing(self, hs: int):
        """Change horizontal spacing between children.

        Parameters
        ----------
        hs : int
        """

    def setIcon(self, ic: FXIcon):
        """Change window icon.

        Parameters
        ----------
        ic : FXIcon
        """

    def setMiniIcon(self, ic: FXIcon):
        """Change window mini (title) icon.

        Parameters
        ----------
        ic : FXIcon
        """

    def setPackingHints(self, ph: int):
        """Change packing hints for children.

        Parameters
        ----------
        ph : int
        """

    def setPadBottom(self, pb: int):
        """Change bottom padding.

        Parameters
        ----------
        pb : int
        """

    def setPadLeft(self, pl: int):
        """Change left padding.

        Parameters
        ----------
        pl : int
        """

    def setPadRight(self, pr: int):
        """Change right padding.

        Parameters
        ----------
        pr : int
        """

    def setPadTop(self, pt: int):
        """Change top padding.

        Parameters
        ----------
        pt : int
        """

    def setTitle(self, name: str):
        """Change window title.

        Parameters
        ----------
        name : str
        """

    def setVSpacing(self, vs: int):
        """Change vertical spacing between children.

        Parameters
        ----------
        vs : int
        """

    def show(self):
        """Show this window.

        Reimplemented from FXWindow. Reimplemented in AFXDialog, AFXFileDialog, and AFXMessageDialog.
        """



from __future__ import annotations

from .FXTopWindow import PLACEMENT_CURSOR, FXTopWindow
from .FXWindow import FXWindow


class FXDialogBox(FXTopWindow):
    """DialogBox window.

    When receiving ID_CANCEL or ID_ACCEPT, the DialogBox breaks out of the modal loop and returns False or
    True, respectively. To close the DialogBox when not running modally, simply send it ID_HIDE.
    """

    #: Closes the dialog, cancel the entry.
    ID_CANCEL: int = hash("ID_CANCEL")

    #: Closes the dialog, accept the entry.
    ID_ACCEPT: int = hash("ID_ACCEPT")

    def __init__(
        self,
        owner: FXWindow,
        name: str,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = 10,
        pr: int = 10,
        pt: int = 10,
        pb: int = 10,
        hs: int = 4,
        vs: int = 4,
    ):
        """Construct dialog which will always float over the owner window.

        Parameters
        ----------
        owner : FXWindow

        name : str

        x : int

        y : int

        w : int

        h : int

        pl : int

        pr : int

        pt : int

        pb : int

        hs : int

        vs : int
        """

    def execute(self, placement: int = PLACEMENT_CURSOR):
        """Run modal invocation of the dialog. Reimplemented in FXInputDialog, and FXReplaceDialog.

        Parameters
        ----------
        placement : int
        """



from __future__ import annotations

from typing import Sequence

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import OFF, Boolean, SymbolicConstant
from .OdbMeshElement import OdbMeshElement
from .OdbMeshElementArray import OdbMeshElementArray
from .OdbMeshNode import OdbMeshNode
from .OdbMeshNodeArray import OdbMeshNodeArray


@abaqus_class_doc
class OdbSet:
    """The set objects are used to identify regions of a model.

    .. note::
        This object can be accessed by::

            import odbAccess
            session.odbs[name].parts[name].elementSets[name]
            session.odbs[name].parts[name].nodeSets[name]
            session.odbs[name].parts[name].surfaces[name]
            session.odbs[name].rootAssembly.elementSets[name]
            session.odbs[name].rootAssembly.instances[name].elementSets[name]
            session.odbs[name].rootAssembly.instances[name].nodeSets[name]
            session.odbs[name].rootAssembly.instances[name].surfaces[name]
            session.odbs[name].rootAssembly.nodeSets[name]
            session.odbs[name].rootAssembly.surfaces[name]
            session.odbs[name].steps[name].frames[i].fieldOutputs[name].values[i].instance.elementSets[name]
            session.odbs[name].steps[name].frames[i].fieldOutputs[name].values[i].instance.nodeSets[name]
            session.odbs[name].steps[name].frames[i].fieldOutputs[name].values[i].instance.surfaces[name]
    """

    #: A String specifying the name of the set and the repository key.
    name: str = ""

    #: A tuple of Strings specifying the namespaces for the nodes, elements, and faces; None if
    #: the set is on a Part or an OdbInstance object.
    instanceNames: tuple = ()

    #: An OdbMeshNodeArray object specifying the nodes of an OdbSet. If a set spans more than
    #: one part instance, this member is a sequence of sequences for each part instance.
    nodes: OdbMeshNodeArray = []

    #: An OdbMeshElementArray object specifying the elements of an OdbSet. If a set spans more
    #: than one part instance, this member is a sequence of sequences for each part instance.
    elements: OdbMeshElementArray = []

    #: A tuple of SymbolicConstants specifying the element face. If a set spans more than one
    #: part instance, this member is a sequence of sequences for each part instance.
    faces: SymbolicConstant

    #: A repository of an OdbInstance object.
    #:
    #: .. versionadded:: 2020
    #:     The ``instances`` attribute was added.
    instances: str = ""

    #: A Boolean specifying whether the set is internal.
    #:
    #: .. versionadded:: 2020
    #:     The ``isInternal`` attribute was added.
    isInternal: Boolean = OFF

    @abaqus_method_doc
    def __init__(self, name: str, nodes: Sequence[OdbMeshNode]):
        """This method creates a node set from an array of OdbMeshNode objects (for part instance-level sets) or
        from a sequence of arrays of OdbMeshNode objects (for assembly-level sets).

        .. note::
            This function can be accessed by::

                session.odbs[name].parts[name].NodeSet
                session.odbs[name].rootAssembly.instances[name].NodeSet
                session.odbs[name].rootAssembly.NodeSet

        Parameters
        ----------
        name
            A String specifying the name of the set and the repository key.
        nodes
            A sequence of OdbMeshNode objects. For example, for a part:`nodes=part1.nodes[1:5]`For
            an assembly:`nodes=(instance1.nodes[6:7], instance2.nodes[1:5])`

        Returns
        -------
        OdbSet
            An OdbSet object.
        """
        ...

    @abaqus_method_doc
    def NodeSetFromNodeLabels(self, name: str, nodeLabels: tuple):
        """This method creates a node set from a sequence of node labels.

        .. note::
            This function can be accessed by::

                session.odbs[name].parts[name].NodeSet
                session.odbs[name].rootAssembly.instances[name].NodeSet
                session.odbs[name].rootAssembly.NodeSet

        Parameters
        ----------
        name
            A String specifying the name of the set and the repository key.
        nodeLabels
            A sequence of node labels. A node label is a sequence of Int node identifiers. For
            example, for a part:`nodeLabels=(2,3,5,7)`For an assembly:`nodeLabels=(('Instance-1',
            (2,3,5,7)), ('Instance-2', (1,2,3)))`

        Returns
        -------
        OdbSet
            An OdbSet object.
        """
        ...

    @abaqus_method_doc
    def ElementSet(self, name: str, elements: Sequence[OdbMeshElement]):
        """This method creates an element set from an array of OdbMeshElement objects (for part instance-level
        sets) or from a sequence of arrays of OdbMeshElement objects (for assembly-level sets).

        .. note::
            This function can be accessed by::

                session.odbs[name].parts[name].NodeSet
                session.odbs[name].rootAssembly.instances[name].NodeSet
                session.odbs[name].rootAssembly.NodeSet

        Parameters
        ----------
        name
            A String specifying the name of the set and the repository key.
        elements
            A sequence of OdbMeshElement objects. For example, for a
            part:`elements=instance1.elements[1:5]`For an
            assembly:`elements=(instance1.elements[1:5], instance2.elements[1:5])`

        Returns
        -------
        OdbSet
            An OdbSet object.
        """
        ...

    @abaqus_method_doc
    def ElementSetFromElementLabels(self, name: str, elementLabels: tuple):
        """This method creates an element set from a sequence of element labels.

        .. note::
            This function can be accessed by::

                session.odbs[name].parts[name].NodeSet
                session.odbs[name].rootAssembly.instances[name].NodeSet
                session.odbs[name].rootAssembly.NodeSet

        Parameters
        ----------
        name
            A String specifying the name of the set and the repository key.
        elementLabels
            A sequence of element labels. An element label is a sequence of Int element identifiers.
            For example, for a part:`elementLabels=(2,3,5,7)`For an
            assembly:`elementLabels=(('Instance-1', (2,3,5,7)), ('Instance-2', (1,2,3)))`

        Returns
        -------
        OdbSet
            An OdbSet object.
        """
        ...

    @abaqus_method_doc
    def MeshSurface(self, name: str, meshSurfaces: tuple):
        """This method creates a surface from the element and side identifiers for the assembly.

        .. note::
            This function can be accessed by::

                session.odbs[name].parts[name].NodeSet
                session.odbs[name].rootAssembly.instances[name].NodeSet
                session.odbs[name].rootAssembly.NodeSet

        Parameters
        ----------
        name
            A String specifying the name of the set and the repository key.
        meshSurfaces
            A sequence of sequences. Each sequence consists of an element sequence and a side
            identifier. The possible side identifiers depend on the type of element, as described in
            the following table:

            | Sequence of elements             | Side identifiers                         |
            | -------------------------------- | ---------------------------------------- |
            | Solid elements                   | FACE1, FACE2, FACE3, FACE4, FACE5, FACE6 |
            | Three-dimensional shell elements | SIDE1, SIDE2                             |
            | Two-dimensional elements         | FACE1, FACE2, FACE3, FACE4               |
            | Wire elements                    | END, END2                                |

            For example::

                side1Elements=instance1.elements[217:218]
                side2Elements=instance2.elements[100:105]
                assembly.MeshSurface(
                    name='Surf-1',
                    meshSurfaces=((side1Elems,SIDE1), (side2Elems,SIDE2))
                )

        Returns
        -------
        OdbSet
            An OdbSet object.
        """
        ...

    @abaqus_method_doc
    def MeshSurfaceFromElsets(self, name: str, elementSetSeq: tuple):
        """This method creates a mesh surface from a sequence of element sets.

        .. note::
            This function can be accessed by::

                session.odbs[name].parts[name].NodeSet
                session.odbs[name].rootAssembly.instances[name].NodeSet
                session.odbs[name].rootAssembly.NodeSet

        Parameters
        ----------
        name
            A String specifying the name of the set and the repository key.
        elementSetSeq
            A sequence of element sets. For example::

                elementSetSeq=((elset1,SIDE1),(elset2,SIDE2))``

            where ``elset1=session.odbs[name].rootAssembly.elementSets['Clutch']``
            and ``SIDE1`` and ``SIDE2`` indicate the side of the element set.

        Returns
        -------
        OdbSet
            An OdbSet object.
        """
        ...

    @abaqus_method_doc
    def MeshSurfaceFromLabels(self, name: str, surfaceLabels: tuple):
        """This method creates a mesh surface from a sequence of surface labels.

        .. note::
            This function can be accessed by::

                session.odbs[name].parts[name].NodeSet
                session.odbs[name].rootAssembly.instances[name].NodeSet
                session.odbs[name].rootAssembly.NodeSet

        Parameters
        ----------
        name
            A String specifying the name of the set and the repository key.
        surfaceLabels
            A sequence of surface labels. For example::

                surfaceLabels=(('Instance-1', ((10, FACE1), (11, FACE2))),  ('Instance-2', ((10, FACE3), (12, FACE4))))

            where ``10`` is an element number and ``FACE1`` indicates the side of the element.

        Returns
        -------
        OdbSet
            An OdbSet object.
        """
        ...



from __future__ import annotations

from .AFXGuiObjectManager import AFXGuiObjectManager
from .FXMenuPane import FXMenuPane


class AFXMenuPane(FXMenuPane):
    """This class provides the interface for creating an FXMenuPane and performing various management activities
    on it."""

    def __init__(self, owner: AFXGuiObjectManager):
        """Constructor.

        Parameters
        ----------
        owner : AFXGuiObjectManager
            Manager of the pane.
        """

    def getOwner(self):
        """Returns the owner of the menu pane.

        Reimplemented from FXWindow.
        """



from __future__ import annotations

from typing import Any

from .FXApp import FXApp
from .FXColor import FXColor
from .FXIcon import FXIcon
from .FXRGB import FXRGB


class FXPNGIcon(FXIcon):
    """Portable Network Graphics (PNG) Icon class."""

    def __init__(
        self,
        a: FXApp,
        pix: Any | None = None,
        clr: FXColor = FXRGB(192, 192, 192),
        opts: int = 0,
        w: int = 1,
        h: int = 1,
    ):
        """Construct an icon from memory stream formatted in PNG format.

        Parameters
        ----------
        a : FXApp

        pix : Any | None

        clr : FXColor

        opts : int

        w : int

        h : int
        """



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import OFF, Boolean
from .Area import Area
from .Chart import Chart
from .Title import Title
from .XYCurve import XYCurve


@abaqus_class_doc
class XYPlotBase:
    """The XYPlot object is used to display Chart objects.

    .. note::
        This object can be accessed by::

            import visualization
            session.xyPlots[name]
    """

    #: An Area object specifying position, padding, background and borders of the XYPlot
    #: object.
    area: Area = Area()

    #: A Title object specifying the title of the XYPlot object.
    title: Title = Title()

    #: A repository of Chart objects.
    charts: dict[str, Chart] = {}

    #: A repository of XYCurve objects.
    curves: dict[str, XYCurve] = {}

    #: A tuple of Floats specifying a transformation matrix used to scale or pan along the axes
    #: of the active Chart object of this XYPlot.
    transform: float | None = None

    @abaqus_method_doc
    def __init__(self, name: str):
        """This method creates an empty XYPlot object.

        .. note::
            This function can be accessed by::

                session.XYPlot

        Parameters
        ----------
        name
            A String specifying the name of the XYPlot object.

        Returns
        -------
        XYPlot
            An XYPlot object.
        """
        ...

    @abaqus_method_doc
    def autoColor(self, lines: Boolean = OFF, symbols: Boolean = OFF):
        """This method distributes the colors on all curves displayed in the XYPlot using the color palette
        defined by the xyColors AutoColors object.

        Parameters
        ----------
        lines
            A Boolean defining whether color distribution affects curve lines.
        symbols
            A Boolean defining whether color distribution affects curve symbols.
        """
        ...

    @abaqus_method_doc
    def autoSymbol(self):
        """This method distributes the symbols on all curves displayed in the XYPlot."""
        ...

    @abaqus_method_doc
    def fitCurves(self):
        """This method resets the transform of all the charts of the XYPlot object.

        It cancels any zoom or pan action.
        """
        ...

    @abaqus_method_doc
    def next(self, drawImmediately: Boolean = False):
        """This method restores the **transform** member of the active Chart object to the next setting in the
        transform list. (There is a list of eight transforms stored for each chart.) If there is no next
        transform, no action is taken.

        Parameters
        ----------
        drawImmediately
            A Boolean specifying the viewport should refresh immediately after the command is
            processed. This is typically only used when writing a script and it is desirable to show
            intermediate results before the script completes. The default value is False.
        """
        ...

    @abaqus_method_doc
    def previous(self, drawImmediately: Boolean = False):
        """This method restores the **transform** member of the active Chart object to the previous setting in
        the transform list. (There is a list of eight transforms stored for each chart.) If there is no next
        transform, no action is taken.

        Parameters
        ----------
        drawImmediately
            A Boolean specifying the viewport should refresh immediately after the command is
            processed. This is typically only used when writing a script and it is desirable to show
            intermediate results before the script completes. The default value is False.
        """
        ...

    @abaqus_method_doc
    def setValues(self, title: Title, transform: tuple):
        """This method modifies the XYPlot object.

        Parameters
        ----------
        title
            A Title object specifying the title of the XYPlot object.
        transform
            A sequence of Floats specifying a transformation matrix used to scale or pan along the
            axes of the active Chart object of this XYPlot.
        """
        ...



from __future__ import annotations

from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import AXIS_1, ROTATION_NONE, SymbolicConstant
from ..UtilityAndView.abaqusConstants import abaqusConstants as C


@abaqus_class_doc
class CompositePly:
    """The CompositePly object defines the material layers in a composite layup.

    .. note::
        This object can be accessed by::

            import section
            mdb.models[name].parts[name].compositeLayups[i].plies[i]
    """

    #: A Float specifying the thickness of the section layer.
    thickness: float

    #: A Region object specifying the region to which the composite ply applies.
    region: Region

    #: A String specifying the name of the material for the ply.
    material: str

    #: A String specifying the ply identifier for this section layer. The default value is an
    #: empty string.
    plyName: str

    #: A SymbolicConstant specifying the method used to define the relative orientation. If
    #: **orientationType** = SPECIFY_ORIENT the **orientationValue** argument is required. If
    #: **orientationType** = CSYS the **orientation** argument is required. Possible values are CSYS,
    #: SPECIFY_ORIENT, ANGLE_0, ANGLE_45, ANGLE_90, and ANGLE_NEG45. The default value is
    #: ANGLE_0.
    orientationType: SymbolicConstant

    #: A SymbolicConstant specifying the method used to define the thickness. If
    #: thicknessType=SPECIFY_THICKNESS, the thickness argument is required.
    #: Possible values are SPECIFY_THICKNESS and FIELD_THICKNESS. The default
    #: value is SPECIFY_THICKNESS.
    #:
    #: .. versionchanged:: 2021
    #:     Add possible value ANALYTICAL_FIELD_THICKNESS.
    thicknessType: SymbolicConstant

    #: A Float specifying the relative orientation of the section layer. The default value is
    #: 0.0.
    orientationValue: float = 0

    #: A String specifying the name of the AnalyticalField or DiscreteField object used to
    #: define the thickness of the shell elements. The thicknessField argument applies only
    #: when thicknessType=ANALYTICAL_FIELD or thicknessType=DISCRETE_FIELD. The default
    #: value is an empty string.
    #:
    #: .. versionchanged:: 2021
    #:     Update docs for ANALYTICAL_FIELD_THICKNESS
    thicknessField: str = ""

    #: An Int specifying the number of integration points to be used through the section layer.
    #: This argument is valid only if **preIntegrate** = OFF. The default value is 3.
    numIntPts: int = 3

    #: A SymbolicConstant specifying the axis of a cylindrical or spherical datum coordinate
    #: system about which an additional rotation is applied. For shells this axis is also the
    #: shell normal. The **axis** argument applies only if a valid reference is provided for the
    #: **orientation**. Possible values are AXIS_1, AXIS_2, and AXIS_3. The default value is
    #: AXIS_1.
    axis: SymbolicConstant = AXIS_1

    #: A Float specifying the angle of the additional rotation. The **angle** argument applies
    #: only if a valid reference is provided for the **orientation**. The default value is 0.0.
    angle: float = 0

    #: A SymbolicConstant specifying the method used to describe the additional rotation when a
    #: valid orientation is specified. Use **orientationType** = ANGLE_0 and
    #: **additionalRotationType** = ROTATION_FIELD to specify a discrete field of rotations for
    #: this CompositePly. Possible values are ROTATION_NONE, ROTATION_ANGLE, and
    #: ROTATION_FIELD. The default value is ROTATION_NONE.
    additionalRotationType: SymbolicConstant = ROTATION_NONE

    #: The SymbolicConstant None or a DatumCsys object specifying a coordinate system reference
    #: for the relative orientation of this layer. The default value is None.
    orientation: SymbolicConstant

    #: A String specifying the name of the field specifying the additional rotation. The
    #: default value is an empty string.
    additionalRotationField: str = ""

    @abaqus_method_doc
    def __init__(
        self,
        thickness: float,
        region: Region,
        material: str,
        plyName: str,
        orientationType: Literal[C.ANGLE_45, C.ANGLE_0, C.CSYS, C.ANGLE_NEG45, C.SPECIFY_ORIENT, C.ANGLE_90],
        thicknessType: Literal[C.FIELD_THICKNESS, C.ANALYTICAL_FIELD_THICKNESS, C.SPECIFY_THICKNESS],
        orientationValue: float = 0,
        thicknessField: str = "",
        numIntPts: int = 3,
        axis: Literal[C.AXIS_1, C.AXIS_3, C.AXIS_2] = AXIS_1,
        angle: float = 0,
        additionalRotationType: Literal[C.ROTATION_NONE, C.ANGLE_0, C.ROTATION_FIELD, C.ROTATION_ANGLE] = ROTATION_NONE,
        orientation: SymbolicConstant | None = None,
        additionalRotationField: str = "",
    ):
        """This method creates a CompositePly object.

        .. note::
            This function can be accessed by::

                mdb.models[name].parts[name].compositeLayups[name].CompositePly

        Parameters
        ----------
        thickness
            A Float specifying the thickness of the section layer.
        region
            A Region object specifying the region to which the composite ply applies.
        material
            A String specifying the name of the material for the ply.
        plyName
            A String specifying the ply identifier for this section layer. The default value is an
            empty string.
        orientationType
            A SymbolicConstant specifying the method used to define the relative orientation. If
            **orientationType** = SPECIFY_ORIENT the **orientationValue** argument is required. If
            **orientationType** = CSYS the **orientation** argument is required. Possible values are CSYS,
            SPECIFY_ORIENT, ANGLE_0, ANGLE_45, ANGLE_90, and ANGLE_NEG45. The default value is
            ANGLE_0.
        thicknessType
            A SymbolicConstant specifying the method used to define the thickness. If
            **thicknessType** = SPECIFY_THICKNESS, the **thickness** argument is required. Possible values
            are SPECIFY_THICKNESS, FIELD_THICKNESS, and ANALYTICAL_FIELD_THICKNESS. The default
            value is SPECIFY_THICKNESS.

            .. versionchanged:: 2021
                Add possible value ANALYTICAL_FIELD_THICKNESS.
        orientationValue
            A Float specifying the relative orientation of the section layer. The default value is
            0.0.
        thicknessField
            A String specifying the name of the AnalyticalField or DiscreteField object used to
            define the thickness of the shell elements and composite ply. The **thicknessField**
            argument applies when **thicknessType** = ANALYTICAL_FIELD or **thicknessType** = DISCRETE_FIELD
            for shell elements and **thicknessType** = FIELD_THICKNESS or
            **thicknessType** = ANALYTICAL_FIELD_THICKNESS for composite ply. The default value is an
            empty string.

            .. versionchanged:: 2021
                Update docs for ANALYTICAL_FIELD_THICKNESS
        numIntPts
            An Int specifying the number of integration points to be used through the section layer.
            This argument is valid only if **preIntegrate** = OFF. The default value is 3.
        axis
            A SymbolicConstant specifying the axis of a cylindrical or spherical datum coordinate
            system about which an additional rotation is applied. For shells this axis is also the
            shell normal. The **axis** argument applies only if a valid reference is provided for the
            **orientation**. Possible values are AXIS_1, AXIS_2, and AXIS_3. The default value is
            AXIS_1.
        angle
            A Float specifying the angle of the additional rotation. The **angle** argument applies
            only if a valid reference is provided for the **orientation**. The default value is 0.0.
        additionalRotationType
            A SymbolicConstant specifying the method used to describe the additional rotation when a
            valid orientation is specified. Use **orientationType** = ANGLE_0 and
            **additionalRotationType** = ROTATION_FIELD to specify a discrete field of rotations for
            this CompositePly. Possible values are ROTATION_NONE, ROTATION_ANGLE, and
            ROTATION_FIELD. The default value is ROTATION_NONE.
        orientation
            The SymbolicConstant None or a DatumCsys object specifying a coordinate system reference
            for the relative orientation of this layer. The default value is None.
        additionalRotationField
            A String specifying the name of the field specifying the additional rotation. The
            default value is an empty string.

        Returns
        -------
        CompositePly
            A CompositePly object.

        Raises
        ------
        AbaqusException
        """
        ...



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc

from ..UtilityAndView.abaqusConstants import SymbolicConstant
from .InteractionState import InteractionState


@abaqus_class_doc
class StdXplCosimulationState(InteractionState):
    """The StdXplCosimulationState object stores the propagating data for a StdXplCosimulation object. One
    instance of this object is created internally by the StdXplCosimulation object for each step. The instance
    is also deleted internally by the StdXplCosimulation object. The StdXplCosimulationState object has no
    constructor or methods. The StdXplCosimulationState object is derived from the InteractionState object.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].steps[name].interactionStates[name]

        The corresponding analysis keywords are:

        - CO-SIMULATION
                - CO-SIMULATION REGION
                - CO-SIMULATION CONTROLS
    """

    #: A SymbolicConstant specifying the propagation state of the InteractionState object.
    #: Possible values are:
    #:
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant



from abqpy.decorators import abaqus_class_doc

from .RayleighDampingByFrequencyComponentArray import (
    RayleighDampingByFrequencyComponentArray,
)


@abaqus_class_doc
class RayleighDampingByFrequency:
    """A RayleighDampingByFrequency object contains Rayleigh Damping parameters.

    .. note::
        This object can be accessed by::

            import step
            mdb.models[name].steps[name].rayleighDampingByFrequency
    """

    #: A RayleighDampingByFrequencyComponentArray object.
    components: RayleighDampingByFrequencyComponentArray = []
